==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/fr/gregorian.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "ce trim.",
	"field-quarter-short-relative+1": "le trim. proch.",
	"dayPeriods-standAlone-abbr-noon": "midi",
	"field-tue-relative+-1": "mardi dernier",
	"field-year": "année",
	"dateFormatItem-yw": "'semaine' w 'de' y",
	"dayPeriods-format-abbr-afternoon1": "ap.m.",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "ce mercredi",
	"field-wed-relative+1": "mercredi prochain",
	"dateFormatItem-ms": "mm:ss",
	"timeFormat-short": "HH:mm",
	"field-minute": "minute",
	"field-tue-narrow-relative+0": "ce mar",
	"field-tue-narrow-relative+1": "mar proch",
	"field-thu-short-relative+0": "ce jeu.",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "aujourd’hui",
	"field-thu-short-relative+1": "jeu. prochain",
	"field-day-relative+1": "demain",
	"field-day-relative+2": "après-demain",
	"field-wed-narrow-relative+-1": "mer dern",
	"field-year-narrow": "a",
	"field-tue-relative+0": "ce mardi",
	"field-tue-relative+1": "mardi prochain",
	"dayPeriods-format-narrow-am": "AM",
	"field-second-short": "s",
	"dayPeriods-standAlone-abbr-morning1": "mat.",
	"dateFormatItem-MMMd": "d MMM",
	"dayPeriods-format-narrow-morning1": "mat.",
	"dayPeriods-format-abbr-am": "AM",
	"field-month-relative+0": "ce mois-ci",
	"field-week-relative+0": "cette semaine",
	"timeFormat-medium": "HH:mm:ss",
	"field-month-relative+1": "le mois prochain",
	"field-week-relative+1": "la semaine prochaine",
	"field-sun-narrow-relative+0": "ce dim",
	"field-mon-short-relative+0": "ce lun.",
	"field-sun-narrow-relative+1": "dim proch",
	"field-mon-short-relative+1": "lun. prochain",
	"field-second-relative+0": "maintenant",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"dayPeriods-standAlone-wide-noon": "midi",
	"eraNames": [
		"avant Jésus-Christ",
		"après Jésus-Christ"
	],
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"field-month-short": "m.",
	"field-day": "jour",
	"dayPeriods-standAlone-wide-night1": "nuit",
	"field-year-relative+-1": "l’année dernière",
	"dayPeriods-format-wide-am": "AM",
	"field-sat-short-relative+-1": "sam. dernier",
	"dayPeriods-format-narrow-afternoon1": "ap.m.",
	"dayPeriods-format-wide-afternoon1": "de l’après-midi",
	"field-hour-relative+0": "cette heure-ci",
	"field-wed-relative+-1": "mercredi dernier",
	"dateTimeFormat-medium": "{1} 'à' {0}",
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"dayPeriods-standAlone-narrow-noon": "midi",
	"field-sat-narrow-relative+-1": "sam dern",
	"field-second": "seconde",
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dateFormat-long": "d MMMM y",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-hour-short-relative+0": "cette h",
	"dayPeriods-standAlone-abbr-midnight": "minuit",
	"field-quarter": "trimestre",
	"field-week-short": "sem.",
	"dayPeriods-format-narrow-midnight": "minuit",
	"dateFormatItem-yMMMEd": "E d MMM y",
	"quarters-standAlone-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"days-format-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"dayPeriods-format-wide-evening1": "du soir",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-tue-short-relative+0": "ce mar.",
	"field-tue-short-relative+1": "mar. prochain",
	"field-mon-relative+-1": "lundi dernier",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "mois",
	"dayPeriods-standAlone-abbr-night1": "nuit",
	"field-day-narrow": "j",
	"dayPeriods-standAlone-narrow-afternoon1": "ap.m.",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min",
	"field-dayperiod": "cadran",
	"field-sat-short-relative+0": "ce sam.",
	"field-sat-short-relative+1": "sam. prochain",
	"dayPeriods-format-narrow-pm": "PM",
	"dateFormat-medium": "d MMM y",
	"eraAbbr": [
		"av. J.-C.",
		"ap. J.-C."
	],
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"dayPeriods-format-abbr-pm": "PM",
	"field-second-narrow": "s",
	"dayPeriods-standAlone-narrow-night1": "nuit",
	"field-mon-relative+0": "ce lundi",
	"field-year-short": "an",
	"field-mon-relative+1": "lundi prochain",
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"dayPeriods-format-wide-morning1": "du matin",
	"field-quarter-relative+-1": "le trimestre dernier",
	"dayPeriods-standAlone-narrow-am": "AM",
	"days-format-short": [
		"di",
		"lu",
		"ma",
		"me",
		"je",
		"ve",
		"sa"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"dayPeriods-format-wide-pm": "PM",
	"field-sat-relative+-1": "samedi dernier",
	"dateTimeFormat-long": "{1} 'à' {0}",
	"dateFormatItem-Md": "dd/MM",
	"field-hour": "heure",
	"field-minute-narrow-relative+0": "cette min",
	"dateFormatItem-yQQQQ": "QQQQ y",
	"months-format-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"dayPeriods-format-wide-night1": "de nuit",
	"dateFormat-full": "EEEE d MMMM y",
	"field-month-relative+-1": "le mois dernier",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "trim.",
	"field-sat-narrow-relative+0": "ce sam",
	"dateFormatItem-Hmv": "HH:mm v",
	"field-fri-relative+0": "ce vendredi",
	"field-sat-narrow-relative+1": "sam proch",
	"field-fri-relative+1": "vendredi prochain",
	"dayPeriods-format-narrow-noon": "midi",
	"field-sun-short-relative+0": "ce dim.",
	"field-sun-short-relative+1": "dim. prochain",
	"field-week-relative+-1": "la semaine dernière",
	"field-quarter-short-relative+-1": "le trim. dern.",
	"dateFormatItem-Ehm": "E h:mm a",
	"field-minute-short-relative+0": "cette min",
	"months-format-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"dayPeriods-format-wide-midnight": "minuit",
	"field-quarter-relative+0": "ce trimestre",
	"timeFormat-long": "HH:mm:ss z",
	"field-minute-relative+0": "cette minute-ci",
	"field-quarter-relative+1": "le trimestre prochain",
	"field-wed-short-relative+-1": "mer. dernier",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormat-short": "dd/MM/y",
	"dayPeriods-format-abbr-night1": "nuit",
	"dateFormatItem-MMMMW": "'semaine' W 'de' MMM",
	"field-thu-short-relative+-1": "jeu. dernier",
	"days-standAlone-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"field-mon-narrow-relative+-1": "lun dern",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "jeu dern",
	"dateFormatItem-E": "E",
	"dateFormatItem-H": "HH 'h'",
	"field-tue-narrow-relative+-1": "mar dern",
	"dayPeriods-format-abbr-evening1": "soir",
	"dayPeriods-standAlone-narrow-pm": "PM",
	"dateFormatItem-M": "L",
	"months-standAlone-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"field-wed-short-relative+0": "ce mer.",
	"field-wed-short-relative+1": "mer. prochain",
	"dateFormatItem-Hmsv": "HH:mm:ss v",
	"field-sun-relative+-1": "dimanche dernier",
	"days-standAlone-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"dateTimeFormat-full": "{1} 'à' {0}",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "jour de la semaine",
	"dayPeriods-standAlone-wide-evening1": "soir",
	"field-quarter-narrow-relative+0": "ce trim",
	"field-sat-relative+0": "ce samedi",
	"dateFormatItem-h": "h a",
	"field-quarter-narrow-relative+1": "trim proch",
	"field-sat-relative+1": "samedi prochain",
	"months-standAlone-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"dateFormatItem-hmsv": "h:mm:ss a v",
	"dayPeriods-format-abbr-morning1": "mat.",
	"dayPeriods-standAlone-narrow-evening1": "soir",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dateFormatItem-MEd": "E dd/MM",
	"dateFormatItem-y": "y",
	"field-thu-narrow-relative+0": "ce jeu",
	"field-sun-narrow-relative+-1": "dim dern",
	"field-mon-short-relative+-1": "lun. dernier",
	"field-thu-narrow-relative+1": "jeu proch",
	"field-thu-relative+0": "ce jeudi",
	"dayPeriods-standAlone-abbr-afternoon1": "ap.m.",
	"field-thu-relative+1": "jeudi prochain",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-fri-short-relative+-1": "ven. dernier",
	"dateFormatItem-hmv": "h:mm a v",
	"dayPeriods-format-abbr-noon": "midi",
	"field-thu-relative+-1": "jeudi dernier",
	"dateFormatItem-yMd": "dd/MM/y",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-week": "semaine",
	"quarters-format-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "ce mer",
	"field-wed-narrow-relative+1": "mer proch",
	"dayPeriods-standAlone-wide-morning1": "matin",
	"field-quarter-narrow-relative+-1": "trim dern",
	"field-fri-short-relative+0": "ce ven.",
	"field-fri-short-relative+1": "ven. prochain",
	"days-standAlone-short": [
		"di",
		"lu",
		"ma",
		"me",
		"je",
		"ve",
		"sa"
	],
	"dayPeriods-standAlone-narrow-morning1": "mat.",
	"field-hour-narrow-relative+0": "cette h",
	"dayPeriods-format-abbr-midnight": "minuit",
	"field-hour-short": "h",
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"field-month-narrow": "m.",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "ven dern",
	"field-year-relative+0": "cette année",
	"field-year-relative+1": "l’année prochaine",
	"field-fri-relative+-1": "vendredi dernier",
	"eraNarrow": [
		"av. J.-C.",
		"ap. J.-C."
	],
	"dayPeriods-format-wide-noon": "midi",
	"field-tue-short-relative+-1": "mar. dernier",
	"field-minute-narrow": "min",
	"dayPeriods-standAlone-wide-afternoon1": "après-midi",
	"dateFormatItem-yQQQ": "QQQ y",
	"days-format-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"field-mon-narrow-relative+0": "ce lun",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-narrow-relative+1": "lun proch",
	"dayPeriods-standAlone-wide-midnight": "minuit",
	"dateFormatItem-yM": "MM/y",
	"field-zone": "fuseau horaire",
	"dateFormatItem-yMMMM": "MMMM y",
	"dateFormatItem-MMMEd": "E d MMM",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-yMEd": "E dd/MM/y",
	"dayPeriods-standAlone-narrow-midnight": "minuit",
	"field-quarter-narrow": "trim.",
	"dayPeriods-standAlone-abbr-am": "AM",
	"field-day-relative+-1": "hier",
	"field-sun-short-relative+-1": "dim. dernier",
	"field-day-relative+-2": "avant-hier",
	"dayPeriods-format-narrow-night1": "nuit",
	"days-format-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"field-sun-relative+0": "ce dimanche",
	"field-sun-relative+1": "dimanche prochain",
	"dateFormatItem-yMMMd": "d MMM y",
	"dateFormatItem-Gy": "y G",
	"field-era": "ère",
	"field-week-narrow": "sem.",
	"field-day-short": "j",
	"dayPeriods-standAlone-abbr-evening1": "soir",
	"field-fri-narrow-relative+0": "ce ven",
	"dayPeriods-format-narrow-evening1": "soir",
	"field-fri-narrow-relative+1": "ven proch",
	"dayPeriods-standAlone-wide-am": "AM"
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/fr/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yMMMM": "MMMM y",
	"field-thu-narrow-relative+0": "ce jeu.",
	"field-thu-narrow-relative+1": "jeu. prochain",
	"field-sun-narrow-relative+0": "ce dim.",
	"field-sun-narrow-relative+1": "dim. prochain",
	"months-format-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-fri-narrow-relative+0": "ce ven.",
	"field-fri-narrow-relative+1": "ven. prochain",
	"eraNarrow": [
		"av. J.-C.",
		"ap. J.-C."
	],
	"dateFormatItem-Hmv": "HH:mm v",
	"dateFormatItem-hmsv": "h:mm:ss a v",
	"dateFormatItem-yMMMd": "d MMM y",
	"dayPeriods-format-abbr-night1": "nuit",
	"dayPeriods-format-narrow-evening1": "soir",
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"days-standAlone-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"dayPeriods-format-abbr-afternoon1": "ap.m.",
	"dayPeriods-format-wide-evening1": "du soir",
	"dateFormatItem-Ehm": "E h:mm a",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-wed-narrow-relative+-1": "mer. dernier",
	"dayPeriods-standAlone-wide-evening1": "soir",
	"field-minute-narrow-relative+0": "cette min",
	"days-format-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"field-month-short-relative+0": "ce mois-ci",
	"field-month-short-relative+1": "le mois prochain",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dayPeriods-standAlone-narrow-evening1": "soir",
	"dayPeriods-standAlone-abbr-afternoon1": "ap.m.",
	"field-thu-relative+0": "ce jeudi",
	"dayPeriods-standAlone-abbr-night1": "nuit",
	"field-thu-relative+1": "jeudi prochain",
	"dayPeriods-format-wide-am": "AM",
	"field-fri-relative+0": "ce vendredi",
	"field-fri-relative+1": "vendredi prochain",
	"dateFormatItem-yMd": "dd/MM/y",
	"field-thu-narrow-relative+-1": "jeu. dernier",
	"field-quarter-relative+0": "ce trimestre",
	"field-quarter-relative+1": "le trimestre prochain",
	"field-sun-short-relative+0": "ce dim.",
	"timeFormat-short": "HH:mm",
	"field-sun-short-relative+1": "dim. prochain",
	"dateFormatItem-hms": "h:mm:ss a",
	"dayPeriods-format-narrow-afternoon1": "ap.m.",
	"dateFormatItem-Md": "dd/MM",
	"dateFormatItem-Hmsv": "HH:mm:ss v",
	"dateFormatItem-hmv": "h:mm a v",
	"field-week-narrow": "sem.",
	"field-hour-relative+0": "cette heure-ci",
	"field-day-relative+-1": "hier",
	"field-day-relative+-2": "avant-hier",
	"field-mon-narrow-relative+-1": "lun. dernier",
	"field-minute-narrow": "min",
	"field-thu-short-relative+0": "ce jeu.",
	"field-mon-relative+0": "ce lundi",
	"field-thu-short-relative+1": "jeu. prochain",
	"field-mon-relative+1": "lundi prochain",
	"field-day-narrow-relative+0": "aujourd’hui",
	"field-era-short": "ère",
	"field-day-narrow-relative+1": "demain",
	"field-sat-narrow-relative+0": "ce sam.",
	"field-day-narrow-relative+2": "après-demain",
	"timeFormat-long": "HH:mm:ss z",
	"field-sat-narrow-relative+1": "sam. prochain",
	"field-week-narrow-relative+0": "cette semaine",
	"field-week-narrow-relative+1": "la semaine prochaine",
	"field-hour-short-relative+0": "cette h",
	"field-wed-narrow-relative+0": "ce mer.",
	"field-wed-narrow-relative+1": "mer. prochain",
	"field-month": "mois",
	"months-standAlone-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"field-weekday-narrow": "j (sem.)",
	"dayPeriods-standAlone-narrow-afternoon1": "ap.m.",
	"field-year-relative+0": "cette année",
	"field-year-relative+1": "l’année prochaine",
	"dayPeriods-format-abbr-evening1": "soir",
	"dayPeriods-format-abbr-noon": "midi",
	"dayPeriods-format-narrow-midnight": "minuit",
	"dayPeriods-format-wide-midnight": "minuit",
	"field-tue-relative+0": "ce mardi",
	"field-tue-relative+1": "mardi prochain",
	"dayPeriods-standAlone-abbr-evening1": "soir",
	"field-minute-short-relative+0": "cette min",
	"dateFormatItem-hm": "h:mm a",
	"dayPeriods-standAlone-wide-midnight": "minuit",
	"field-year-narrow": "a",
	"dayPeriods-standAlone-abbr-noon": "midi",
	"field-tue-short-relative+0": "ce mar.",
	"dayPeriods-standAlone-narrow-midnight": "minuit",
	"field-tue-short-relative+1": "mar. prochain",
	"field-tue-narrow-relative+0": "ce mar.",
	"field-tue-narrow-relative+1": "mar. prochain",
	"dateTimeFormat-full": "{1} 'à' {0}",
	"dateFormatItem-E": "E",
	"dateFormatItem-EBhm": "E h:mm B",
	"dateFormatItem-H": "HH 'h'",
	"field-wed-relative+0": "ce mercredi",
	"field-wed-relative+1": "mercredi prochain",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "ce mer.",
	"field-fri-short-relative+0": "ce ven.",
	"field-wed-short-relative+1": "mer. prochain",
	"field-fri-short-relative+1": "ven. prochain",
	"field-weekOfMonth-short": "sem. (m.)",
	"field-quarter-short-relative+-1": "le trim. dern.",
	"field-year-short-relative+-1": "l’année dernière",
	"dateFormatItem-Bhm": "h:mm B",
	"dayPeriods-format-wide-night1": "du matin",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-quarter-narrow-relative+-1": "trim. dern.",
	"dateFormatItem-d": "d",
	"dayPeriods-format-abbr-pm": "PM",
	"dateFormatItem-h": "h a",
	"quarters-standAlone-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"field-weekOfMonth-narrow": "sem. (m.)",
	"dateFormatItem-y": "y",
	"field-minute-relative+0": "cette minute-ci",
	"field-year-short-relative+0": "cette année",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-year-short-relative+1": "l’année prochaine",
	"field-weekday": "jour de la semaine",
	"dayPeriods-format-narrow-pm": "PM",
	"field-tue-narrow-relative+-1": "mar. dernier",
	"dateFormatItem-yMEd": "E dd/MM/y",
	"dayPeriods-standAlone-wide-night1": "nuit",
	"field-year-narrow-relative+-1": "l’année dernière",
	"field-sat-relative+-1": "samedi dernier",
	"dayPeriods-format-abbr-midnight": "minuit",
	"dayPeriods-format-narrow-morning1": "mat.",
	"dayPeriods-format-wide-morning1": "du matin",
	"dayPeriods-standAlone-abbr-midnight": "minuit",
	"dayPeriods-standAlone-narrow-pm": "PM",
	"dayPeriods-standAlone-wide-morning1": "matin",
	"field-mon-narrow-relative+0": "ce lun.",
	"field-mon-narrow-relative+1": "lun. prochain",
	"field-second": "seconde",
	"dateFormatItem-yMMMEd": "E d MMM y",
	"field-year-relative+-1": "l’année dernière",
	"field-weekdayOfMonth-short": "jour (mois)",
	"dateFormat-short": "dd/MM/y",
	"eraNames": [
		"avant Jésus-Christ",
		"après Jésus-Christ"
	],
	"field-second-short": "s",
	"field-thu-short-relative+-1": "jeu. dernier",
	"field-zone": "fuseau horaire",
	"field-dayperiod-narrow": "cadran",
	"field-sun-short-relative+-1": "dim. dernier",
	"dayPeriods-standAlone-narrow-morning1": "mat.",
	"eraAbbr": [
		"av. J.-C.",
		"ap. J.-C."
	],
	"field-week-short": "sem.",
	"dayPeriods-standAlone-abbr-am": "AM",
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+0": "aujourd’hui",
	"field-day-relative+1": "demain",
	"field-day-relative+2": "après-demain",
	"field-day-short-relative+0": "aujourd’hui",
	"field-dayOfYear-short": "j (an)",
	"field-day-short-relative+1": "demain",
	"dateFormat-long": "d MMMM y",
	"field-day-short-relative+2": "après-demain",
	"field-sun-narrow-relative+-1": "dim. dernier",
	"dayPeriods-format-wide-noon": "midi",
	"field-second-relative+0": "maintenant",
	"field-quarter-relative+-1": "le trimestre dernier",
	"dayPeriods-format-narrow-night1": "nuit",
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"dayPeriods-standAlone-wide-noon": "midi",
	"dayPeriods-standAlone-narrow-night1": "nuit",
	"field-week-relative+-1": "la semaine dernière",
	"dayPeriods-format-abbr-morning1": "mat.",
	"field-month-relative+-1": "le mois dernier",
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year": "année",
	"field-era": "ère",
	"dayPeriods-standAlone-abbr-morning1": "mat.",
	"days-standAlone-short": [
		"di",
		"lu",
		"ma",
		"me",
		"je",
		"ve",
		"sa"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"dateFormatItem-yQQQQ": "QQQQ y",
	"field-day-short-relative+-1": "hier",
	"field-day-short-relative+-2": "avant-hier",
	"dateFormatItem-GyMMM": "MMM y G",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-hour": "heure",
	"field-dayOfYear-narrow": "j (an)",
	"field-quarter": "trimestre",
	"field-month-narrow-relative+0": "ce mois-ci",
	"field-month-narrow-relative+1": "le mois prochain",
	"field-day": "jour",
	"field-mon-relative+-1": "lundi dernier",
	"field-dayOfYear": "jour (année)",
	"dateFormat-medium": "d MMM y",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"dateFormatItem-MEd": "E dd/MM",
	"field-tue-short-relative+-1": "mar. dernier",
	"field-year-short": "an",
	"field-month-short": "m.",
	"dateFormatItem-MMMEd": "E d MMM",
	"dayPeriods-format-wide-afternoon1": "de l’après-midi",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-Bh": "h B",
	"months-format-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"dayPeriods-format-abbr-am": "AM",
	"field-sat-relative+0": "ce samedi",
	"field-sat-relative+1": "samedi prochain",
	"dayPeriods-format-wide-pm": "PM",
	"days-standAlone-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"field-zone-short": "fuseau horaire",
	"field-week-short-relative+0": "cette semaine",
	"field-week-short-relative+1": "la semaine prochaine",
	"dayPeriods-standAlone-wide-afternoon1": "après-midi",
	"field-fri-short-relative+-1": "ven. dernier",
	"field-month-narrow": "m.",
	"dayPeriods-format-narrow-am": "AM",
	"field-month-narrow-relative+-1": "le mois dernier",
	"days-format-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"field-weekday-short": "j (sem.)",
	"field-day-narrow-relative+-1": "hier",
	"field-day-narrow-relative+-2": "avant-hier",
	"field-quarter-short": "trim.",
	"days-format-short": [
		"di",
		"lu",
		"ma",
		"me",
		"je",
		"ve",
		"sa"
	],
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"days-format-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"dateFormatItem-EHm": "E HH:mm",
	"field-quarter-narrow": "trim.",
	"field-mon-short-relative+0": "ce lun.",
	"field-mon-short-relative+1": "lun. prochain",
	"field-dayperiod-short": "cadran",
	"dayPeriods-standAlone-narrow-am": "AM",
	"field-week-narrow-relative+-1": "la semaine dernière",
	"field-thu-relative+-1": "jeudi dernier",
	"field-fri-narrow-relative+-1": "ven. dernier",
	"field-mon-short-relative+-1": "lun. dernier",
	"timeFormat-medium": "HH:mm:ss",
	"field-quarter-short-relative+0": "ce trim.",
	"field-quarter-short-relative+1": "le trim. proch.",
	"dateFormatItem-Ed": "E d",
	"field-wed-relative+-1": "mercredi dernier",
	"field-weekOfMonth": "semaine (mois)",
	"field-weekdayOfMonth-narrow": "jour (mois)",
	"dayPeriods-standAlone-wide-am": "AM",
	"dateFormatItem-yQQQ": "QQQ y",
	"field-fri-relative+-1": "vendredi dernier",
	"field-minute": "minute",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"quarters-format-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"field-day-short": "j",
	"field-dayperiod": "cadran",
	"field-hour-short": "h",
	"months-standAlone-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"field-month-relative+0": "ce mois-ci",
	"field-second-narrow": "s",
	"field-month-relative+1": "le mois prochain",
	"dateFormat-full": "EEEE d MMMM y",
	"field-era-narrow": "ère",
	"field-sat-short-relative+-1": "sam. dernier",
	"dayPeriods-format-narrow-noon": "midi",
	"field-week-short-relative+-1": "la semaine dernière",
	"dateTimeFormat-long": "{1} 'à' {0}",
	"dateFormatItem-yM": "MM/y",
	"field-sun-relative+-1": "dimanche dernier",
	"field-wed-short-relative+-1": "mer. dernier",
	"field-weekdayOfMonth": "jour (mois)",
	"field-quarter-narrow-relative+0": "ce trim.",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"field-quarter-narrow-relative+1": "trim. proch.",
	"field-sat-short-relative+0": "ce sam.",
	"field-hour-narrow": "h",
	"field-sat-short-relative+1": "sam. prochain",
	"field-year-narrow-relative+0": "cette année",
	"field-year-narrow-relative+1": "l’année prochaine",
	"dateFormatItem-Gy": "y G",
	"field-zone-narrow": "fuseau horaire",
	"dayPeriods-standAlone-narrow-noon": "midi",
	"field-tue-relative+-1": "mardi dernier",
	"field-minute-short": "min",
	"dateFormatItem-yw": "'semaine' w 'de' Y",
	"dateFormatItem-Hm": "HH:mm",
	"field-week-relative+0": "cette semaine",
	"field-week-relative+1": "la semaine prochaine",
	"dateFormatItem-MMM": "LLL",
	"field-sun-relative+0": "ce dimanche",
	"field-sun-relative+1": "dimanche prochain",
	"field-sat-narrow-relative+-1": "sam. dernier",
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"dateFormatItem-MMMMW": "'semaine' W (MMMM)",
	"field-month-short-relative+-1": "le mois dernier",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-hour-narrow-relative+0": "cette h",
	"field-week": "semaine",
	"field-day-narrow": "j"
}
//end v1.x content
);
